globalVariables(
  names = c(
    "d", "density", "dx", "dy", "p", "sd", "sim_number", "x", "y",
    ".n",".num_sims","dist_name","random_walk_value","results",
    "dist_type","var","shape","rec_no","value"
  )
)
